@@ -98,6 +98,9 @@ fragment stepEventFragment on StepEvent {
         ...metadataEntryFragment
       }
     }
+    metadataEntries {
+      ...metadataEntryFragment
+    }
   }
 
   ... on ExecutionStepUpForRetryEvent {
@@ -142,6 +145,7 @@ fragment stepEventFragment on StepEvent {
     message
     timestamp
     level
+    eventType
   }
 
 
@@ -157,6 +161,7 @@ fragment messageEventFragment on MessageEvent {
   message
   timestamp
   level
+  eventType
   ...stepEventFragment
   ... on PipelineInitFailureEvent {
     initError: error {
@@ -345,7 +350,7 @@ query ReexecutionInfoQuery($runId: ID!) {
 LAUNCH_PARTITION_BACKFILL_MUTATION = (
     ERROR_FRAGMENT
     + """
-mutation($backfillParams: PartitionBackfillParams!) {
+mutation($backfillParams: LaunchBackfillParams!) {
   launchPartitionBackfill(backfillParams: $backfillParams) {
     __typename
     ... on PythonError {
@@ -354,7 +359,7 @@ mutation($backfillParams: PartitionBackfillParams!) {
     ... on PartitionSetNotFoundError {
       message
     }
-    ... on PartitionBackfillSuccess {
+    ... on LaunchBackfillSuccess {
       backfillId
       launchedRunIds
     }
@@ -362,20 +367,3 @@ mutation($backfillParams: PartitionBackfillParams!) {
 }
 """
 )
-
-LAUNCH_TRIGGERED_EXECUTION = (
-    ERROR_FRAGMENT
-    + """
-mutation($triggerSelector: TriggerSelector!) {
-  triggerExecution(triggerSelector: $triggerSelector) {
-    __typename
-    ... on PythonError {
-      ...errorFragment
-    }
-    ... on TriggerExecutionSuccess {
-      launchedRunIds
-    }
-  }
-}
-  """
-)
