@@ -1,10 +1,11 @@
 import graphene
 from dagster import check
-from dagster.core.events import DagsterEventType
+from dagster.core.events import AssetLineageInfo, DagsterEventType
+from dagster.core.execution.plan.objects import ErrorSource
 from dagster.core.execution.stats import RunStepKeyStatsSnapshot
 
 from ...implementation.fetch_runs import get_step_stats
-from ..asset_key import GrapheneAssetKey
+from ..asset_key import GrapheneAssetKey, GrapheneAssetLineageInfo
 from ..errors import GraphenePythonError
 from ..runs import GrapheneStepEventStatus
 from ..util import non_null_list
@@ -311,7 +312,7 @@ class GrapheneExecutionStepInputEvent(graphene.ObjectType):
 
 class GrapheneExecutionStepOutputEvent(graphene.ObjectType):
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneStepEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneStepEvent, GrapheneDisplayableEvent)
         name = "ExecutionStepOutputEvent"
 
     output_name = graphene.NonNull(graphene.String)
@@ -330,6 +331,7 @@ class GrapheneExecutionStepFailureEvent(graphene.ObjectType):
         name = "ExecutionStepFailureEvent"
 
     error = graphene.NonNull(GraphenePythonError)
+    errorSource = graphene.Field(graphene.Enum.from_enum(ErrorSource))
     failureMetadata = graphene.Field(GrapheneFailureMetadata)
 
 
@@ -360,6 +362,11 @@ class GrapheneStepMaterializationEvent(graphene.ObjectType):
 
     materialization = graphene.NonNull(GrapheneMaterialization)
     stepStats = graphene.NonNull(lambda: GraphenePipelineRunStepStats)
+    assetLineage = non_null_list(GrapheneAssetLineageInfo)
+
+    def __init__(self, materialization, assetLineage, **basic_params):
+        self._asset_lineage = check.opt_list_param(assetLineage, "assetLineage", AssetLineageInfo)
+        super().__init__(materialization=materialization, **basic_params)
 
     def resolve_stepStats(self, graphene_info):
         run_id = self.runId  # pylint: disable=no-member
@@ -367,10 +374,19 @@ class GrapheneStepMaterializationEvent(graphene.ObjectType):
         stats = get_step_stats(graphene_info, run_id, step_keys=[step_key])
         return stats[0]
 
+    def resolve_assetLineage(self, _graphene_info):
+        return [
+            GrapheneAssetLineageInfo(
+                assetKey=lineage_info.asset_key,
+                partitions=lineage_info.partitions,
+            )
+            for lineage_info in self._asset_lineage
+        ]
+
 
 class GrapheneHandledOutputEvent(graphene.ObjectType):
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneStepEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneStepEvent, GrapheneDisplayableEvent)
         name = "HandledOutputEvent"
 
     output_name = graphene.NonNull(graphene.String)
