@@ -4,7 +4,7 @@ from dagster.core.host_representation import RepositoryLocationHandleManager
 from dagster.core.host_representation.grpc_server_registry import ProcessGrpcServerRegistry
 from dagster.core.scheduler.job import JobState, JobStatus
 from dagster.daemon import get_default_daemon_logger
-from dagster.scheduler.sensor import execute_sensor_iteration
+from dagster.daemon.sensor import execute_sensor_iteration
 from dagster_graphql.test.utils import (
     execute_dagster_graphql,
     infer_repository_selector,
